@@ -5,7 +5,7 @@ from __future__ import absolute_import
 import os
 import sys
 import argparse
-import click
+from tools import click
 
 from bowler import Query
 
@@ -26,14 +26,15 @@ def should_convert(inpath):
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("--log-level", dest="log_level", type=str, choices=["DEBUG", "INFO", "WARNING", "ERROR"], help="Set log level, default is INFO")
-    parser.add_argument("--no-log-file", dest="no_log_file", action='store_true', default=False, help="Don't log to file")
-    parser.add_argument("--log-filepath", dest="log_filepath", type=str, help='Set log file path, default is "report.log"')
-    parser.add_argument("--inpath", required=True, type=str, help='The file or directory path you want to upgrade.')
+    parser.add_argument("--log-level", dest="log_level", type=str, choices=["DEBUG", "INFO", "WARNING", "ERROR"], help="set log level, default is INFO")
+    parser.add_argument("--no-log-file", dest="no_log_file", action='store_true', default=False, help="don't log to file")
+    parser.add_argument("--log-filepath", dest="log_filepath", type=str, help='set log file path, default is "report.log"')
+    parser.add_argument("--inpath", required=True, type=str, help='the file or directory path you want to upgrade.')
     parser.add_argument("--backup", type=str, nargs='?', default=None, const=None, help='backup directory, default is the "~/.paddle1to2/".')
-    parser.add_argument("--write", action='store_true', default=False, help='Modify files in place.')
-    parser.add_argument("--refactor", action='append', choices=refactor.__all__, help='This is a debug option. Specify refactor you want to run. If none, all refactors will be run.')
-    parser.add_argument("--print-match", action='store_true', default=False, help='This is a debug option. Print matched code and node for each file.')
+    parser.add_argument("--write", action='store_true', default=False, help='modify files in-place.')
+    parser.add_argument("--no-confirm", dest="no_confirm", action='store_true', default=False, help='write files in-place without confirm, ignored without --write.')
+    parser.add_argument("--refactor", action='append', choices=refactor.__all__, help='this is a debug option. Specify refactor you want to run. If none, all refactors will be run.')
+    parser.add_argument("--print-match", action='store_true', default=False, help='this is a debug option. Print matched code and node for each file.')
 
     args = parser.parse_args()
     if args.refactor:
@@ -66,18 +67,20 @@ def main():
             refactor_func(q, change_spec)
 
     if args.write:
-        if click.confirm(click.style("Files will be modified in-place, but don't worry, we will backup your files to {} automatically. do you want to continue?".format(args.backup), fg='red', bold=True)):
-            # backup args.inpath
-            backup_inpath(args.inpath, args.backup)
-            # print diff to stdout, and modify file in place.
-            q.execute(interactive=False, write=True, silent=False)
-            logger.info("Refactor finished, and source files are modified in-place. Recover your files from {} if anything is wrong.".format(args.backup))
+        # backup args.inpath
+        backup = backup_inpath(args.inpath, args.backup)
+        # print diff to stdout, and modify file in place.
+        if utils.is_windows():
+            q.execute(write=True, silent=False, need_confirm=not args.no_confirm, backup=backup, in_process=True)
         else:
-            click.secho('Refactor abort!', fg='red', bold=True)
+            q.execute(write=True, silent=False, need_confirm=not args.no_confirm, backup=backup)
     else:
         # print diff to stdout
-        q.execute(interactive=False, write=False, silent=False)
-        logger.warning('Refactor finished without touching source files, add "--write" to modify source files in-place if everything is ok.')
+        if utils.is_windows():
+            q.execute(write=False, silent=False, in_process=True)
+        else:
+            q.execute(write=False, silent=False)
+        click.secho('Refactor finished without touching source files, add "--write" to modify source files in-place if everything is ok.', fg="red", bold=True)
 
 if __name__ == "__main__":
     sys.exit(main())
